==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-MX/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Más información",

    "audit_help" => "Al marcar esta casilla se editará el activo para reflejar esta nueva ubicación. Dejarla desmarcada simplemente anotará la ubicación en la auditoría.<br><br>Tenga en cuenta que este activo está asignado, no se cambiará la ubicación de la persona, activo o ubicación de donde está asignado.",

    'assets' => 'Los activos son elementos rastreados por número de serie o etiqueta de activos. Suelen ser artículos de alto valor donde la identificación del activo importa.',

    'categories' => 'Las categorías te ayudan a organizar los activos. Ejemplos de categorías: &quot;Pcs&quot;, &quot;Portátiles&quot;, &quot;Móviles&quot;, &quot;Tabletas&quot;, etc.',

    'accessories' => 'Accesorios son cualquier cosa que entregues a los usuarios pero que no tenga numero de serie (o no te interese seguirlos en forma única). Por ejemplo, ratones o teclados.',

    'companies'     => 'Las empresas pueden ser utilizadas como un campo identificador simple, o pueden ser utilizadas para limitar la visibilidad de los activos, usuarios, etc si el soporte completo de la empresa está habilitado en la configuración del Administrador.',

    'components'    => 'Los componentes son elementos que son parte de un activo, por ejemplo HDD, RAM, etc.',

    'consumables'   => 'Los consumibles son cualquier cosa comprada que se usará con el tiempo. Por ejemplo, tinta de impresora o papel copiador.',

    'depreciations' => 'Puede configurar depreciaciones de activos para depreciar activos basados en una depreciación lineal.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-MX/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Más información',

    'audit_help' => 'Al marcar esta casilla se editará el activo para reflejar esta nueva ubicación. Dejarla desmarcada simplemente anotará la ubicación en la auditoría.<br><br>Tenga en cuenta que este activo está asignado, no se cambiará la ubicación de la persona, activo o ubicación de donde está asignado.',

    'assets' => 'Los activos son elementos rastreados por número de serie o etiqueta de activos. Suelen ser artículos de alto valor donde la identificación del activo importa.',

    'categories' => 'Las categorías te ayudan a organizar los activos. Ejemplos de categorías: &quot;Pcs&quot;, &quot;Portátiles&quot;, &quot;Móviles&quot;, &quot;Tabletas&quot;, etc.',

    'accessories' => 'Accesorios son cualquier cosa que entregues a los usuarios pero que no tenga numero de serie (o no te interese seguirlos en forma única). Por ejemplo, ratones o teclados.',

    'companies'     => 'Las empresas pueden ser utilizadas como un campo identificador simple, o pueden ser utilizadas para limitar la visibilidad de los activos, usuarios, etc si el soporte completo de la empresa está habilitado en la configuración del Administrador.',

    'components'    => 'Los componentes son elementos que son parte de un activo, por ejemplo HDD, RAM, etc.',

    'consumables'   => 'Los consumibles son cualquier cosa comprada que se usará con el tiempo. Por ejemplo, tinta de impresora o papel copiador.',

    'depreciations' => 'Puede configurar depreciaciones de activos para depreciar activos basados en una depreciación lineal.',

];
